@@ -51,12 +51,8 @@
 #endif
 
 #include "tool_cfgable.h"
-#include "tool_cb_dbg.h"
 #include "tool_cb_hdr.h"
 #include "tool_cb_prg.h"
-#include "tool_cb_rea.h"
-#include "tool_cb_see.h"
-#include "tool_cb_soc.h"
 #include "tool_cb_wrt.h"
 #include "tool_dirhie.h"
 #include "tool_doswin.h"
@@ -64,7 +60,6 @@
 #include "tool_filetime.h"
 #include "tool_getparam.h"
 #include "tool_helpers.h"
-#include "tool_findfile.h"
 #include "tool_libinfo.h"
 #include "tool_main.h"
 #include "tool_msgs.h"
@@ -84,6 +79,7 @@
 #include "tool_progress.h"
 #include "tool_ipfs.h"
 #include "config2setopts.h"
+#include "var.h"
 
 #ifdef DEBUGBUILD
 /* libcurl's debug-only curl_easy_perform_ev() */
@@ -350,14 +346,14 @@ static bool is_outfile_auto_resumable(struct OperationConfig *config,
 {
   struct OutStruct *outs = &per->outs;
   return config->use_resume && config->resume_from_current &&
-         config->resume_from >= 0 && outs->init == config->resume_from &&
-         outs->bytes > 0 && outs->filename && outs->s_isreg && outs->fopened &&
-         outs->stream && !ferror(outs->stream) &&
-         !config->customrequest && !per->uploadfile &&
-         (config->httpreq == TOOL_HTTPREQ_UNSPEC ||
-          config->httpreq == TOOL_HTTPREQ_GET) &&
-         /* CURLE_WRITE_ERROR could mean outs->bytes is not accurate */
-         result != CURLE_WRITE_ERROR && result != CURLE_RANGE_ERROR;
+    config->resume_from >= 0 && outs->init == config->resume_from &&
+    outs->bytes > 0 && outs->filename && outs->regular_file && outs->fopened &&
+    outs->stream && !ferror(outs->stream) &&
+    !config->customrequest && !per->uploadfile &&
+    (config->httpreq == TOOL_HTTPREQ_UNSPEC ||
+     config->httpreq == TOOL_HTTPREQ_GET) &&
+    /* CURLE_WRITE_ERROR could mean outs->bytes is not accurate */
+    result != CURLE_WRITE_ERROR && result != CURLE_RANGE_ERROR;
 }
 
 static CURLcode retrycheck(struct OperationConfig *config,
@@ -611,22 +607,21 @@ static CURLcode post_per_transfer(struct per_transfer *per,
   if(!curl || !config)
     return result;
 
+#ifdef _WIN32
   if(per->uploadfile) {
     if(!strcmp(per->uploadfile, ".") && per->infd > 0) {
-#if defined(_WIN32) && !defined(CURL_WINDOWS_UWP)
+#ifndef CURL_WINDOWS_UWP
       sclose(per->infd);
 #else
-      warnf("Closing per->infd != 0: FD == "
-            "%d. This behavior is only supported on desktop "
-            " Windows", per->infd);
+      warnf("Closing per->infd != 0: FD == %d. "
+            "This behavior is only supported on desktop Windows", per->infd);
 #endif
     }
   }
-  else {
-    if(per->infdopen) {
+  else
+#endif
+    if(per->infdopen)
       close(per->infd);
-    }
-  }
 
   if(per->skip)
     goto skip;
@@ -637,28 +632,27 @@ static CURLcode post_per_transfer(struct per_transfer *per,
     if(global->silent && !global->showerror)
       vms_show = VMSSTS_HIDE;
   }
-  else
 #endif
-    if(!config->synthetic_error && result &&
-       (!global->silent || global->showerror)) {
-      const char *msg = per->errorbuffer;
-      curl_mfprintf(tool_stderr, "curl: (%d) %s\n", result,
-                    msg[0] ? msg : curl_easy_strerror(result));
-      if(result == CURLE_PEER_FAILED_VERIFICATION)
-        fputs(CURL_CA_CERT_ERRORMSG, tool_stderr);
-    }
-    else if(config->fail == FAIL_WITH_BODY) {
-      /* if HTTP response >= 400, return error */
-      long code = 0;
-      curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &code);
-      if(code >= 400) {
-        if(!global->silent || global->showerror)
-          curl_mfprintf(tool_stderr,
-                        "curl: (%d) The requested URL returned error: %ld\n",
-                        CURLE_HTTP_RETURNED_ERROR, code);
-        result = CURLE_HTTP_RETURNED_ERROR;
-      }
+  if(!config->synthetic_error && result &&
+     (!global->silent || global->showerror)) {
+    const char *msg = per->errorbuffer;
+    curl_mfprintf(tool_stderr, "curl: (%d) %s\n", result,
+                  msg[0] ? msg : curl_easy_strerror(result));
+    if(result == CURLE_PEER_FAILED_VERIFICATION)
+      fputs(CURL_CA_CERT_ERRORMSG, tool_stderr);
+  }
+  else if(config->fail == FAIL_WITH_BODY) {
+    /* if HTTP response >= 400, return error */
+    long code = 0;
+    curl_easy_getinfo(curl, CURLINFO_RESPONSE_CODE, &code);
+    if(code >= 400) {
+      if(!global->silent || global->showerror)
+        curl_mfprintf(tool_stderr,
+                      "curl: (%d) The requested URL returned error: %ld\n",
+                      CURLE_HTTP_RETURNED_ERROR, code);
+      result = CURLE_HTTP_RETURNED_ERROR;
     }
+  }
   /* Set file extended attributes */
   if(!result && config->xattr && outs->fopened && outs->stream) {
     rc = fwrite_xattr(curl, per->url, fileno(outs->stream));
@@ -681,7 +675,7 @@ static CURLcode post_per_transfer(struct per_transfer *per,
       result = CURLE_WRITE_ERROR;
   }
 
-  if(!outs->s_isreg && outs->stream) {
+  if(!outs->regular_file && outs->stream) {
     /* Dump standard stream buffered data */
     rc = fflush(outs->stream);
     if(!result && rc) {
@@ -736,7 +730,7 @@ static CURLcode post_per_transfer(struct per_transfer *per,
   }
 
   /* File time can only be set _after_ the file has been closed */
-  if(!result && config->remote_time && outs->s_isreg && outs->filename) {
+  if(!result && config->remote_time && outs->regular_file && outs->filename) {
     /* Ask libcurl if we got a remote file time */
     curl_off_t filetime = -1;
     curl_easy_getinfo(curl, CURLINFO_FILETIME_T, &filetime);
@@ -908,7 +902,7 @@ static CURLcode etag_store(struct OperationConfig *config,
     }
     else {
       etag_save->filename = config->etag_save_file;
-      etag_save->s_isreg = TRUE;
+      etag_save->regular_file = TRUE;
       etag_save->fopened = TRUE;
       etag_save->stream = newfile;
     }
@@ -961,7 +955,7 @@ static CURLcode setup_headerfile(struct OperationConfig *config,
     }
     else {
       heads->filename = config->headerfile;
-      heads->s_isreg = TRUE;
+      heads->regular_file = TRUE;
       heads->fopened = TRUE;
       heads->stream = newfile;
     }
@@ -1073,7 +1067,7 @@ static CURLcode setup_outfile(struct OperationConfig *config,
     outs->stream = NULL; /* open when needed */
   }
   outs->filename = per->outfile;
-  outs->s_isreg = TRUE;
+  outs->regular_file = TRUE;
   return CURLE_OK;
 }
 
@@ -1701,7 +1695,7 @@ static CURLcode parallel_event(struct parastate *s)
   }
 
   /* We need to cleanup the multi here, since the uv context lives on the
-   * stack and will be gone. multi_cleanup can triggere events! */
+   * stack and will be gone. multi_cleanup can trigger events! */
   curl_multi_cleanup(s->multi);
 
 #if DEBUG_UV
