@@ -23,11 +23,9 @@
  ***************************************************************************/
 #include "first.h"
 
-#include "memdebug.h"
-
-static CURLcode test_lib3103(char *URL)
+static CURLcode test_lib3103(const char *URL)
 {
-  CURLcode res = CURLE_OK;
+  CURLcode result = CURLE_OK;
   CURLSH *share;
   CURL *curl;
 
@@ -49,10 +47,10 @@ static CURLcode test_lib3103(char *URL)
   /* Set a cookie without Max-age or Expires */
   test_setopt(curl, CURLOPT_COOKIELIST, "Set-Cookie: c1=v1; domain=localhost");
 
-  res = curl_easy_perform(curl);
-  if(res) {
+  result = curl_easy_perform(curl);
+  if(result) {
     curl_mfprintf(stderr, "curl_easy_perform() failed: %s\n",
-                  curl_easy_strerror(res));
+                  curl_easy_strerror(result));
   }
 
 test_cleanup:
@@ -62,5 +60,5 @@ test_cleanup:
   curl_share_cleanup(share);
   curl_global_cleanup();
 
-  return res;
+  return result;
 }
